classdef FunSysFunction < Function
    
    properties(SetAccess = private)
        functionSystem
        coordinates
    end
    
    methods
        function obj = FunSysFunction(funSys, coord)
           if ~isa(funSys, 'FunctionSystem')
              error('First argument must be of type FunctionSystem.'); 
           end
           
           if ~isvector(coord)
              error('Second parameter must be a vector.'); 
           end
           
           if (length(coord) ~= funSys.N)
              error(['The number of coordinates does not match ' ...
                    'the number of functionals in the functional system.']);
           end
           
           obj.functionSystem = funSys;
           %Make sure that the coordinates are a row vector
           obj.coordinates = reshape(coord, 1, length(coord));
        end
        
        function y = of(obj, x)
            if ~isscalar(x)
               error('The argument must be a scalar.'); 
            end
           
            y = obj.coordinates * obj.functionSystem.evaluate(x);
        end
    end
    
end

